@@ -21,10 +21,13 @@
  * Author: Christian Kellner <gicmo@gnome.org> 
  */
 
-#include <config.h>
+#include "config.h"
 #include "gbufferedinputstream.h"
 #include "ginputstream.h"
+#include "gcancellable.h"
+#include "gasyncresult.h"
 #include "gsimpleasyncresult.h"
+#include "gioerror.h"
 #include <string.h>
 #include "glibintl.h"
 
@@ -33,7 +36,7 @@
 /**
  * SECTION:gbufferedinputstream
  * @short_description: Buffered Input Stream
- * @include: gio.h
+ * @include: gio/gio.h
  * @see_also: #GFilterInputStream, #GInputStream
  * 
  * Buffered input stream implements #GFilterInputStream and provides 
@@ -298,8 +301,7 @@ g_buffered_input_stream_finalize (GObject *object)
 
   g_free (priv->buffer);
 
-  if (G_OBJECT_CLASS (g_buffered_input_stream_parent_class)->finalize)
-    (*G_OBJECT_CLASS (g_buffered_input_stream_parent_class)->finalize) (object);
+  G_OBJECT_CLASS (g_buffered_input_stream_parent_class)->finalize (object);
 }
 
 static void
@@ -336,7 +338,7 @@ g_buffered_input_stream_new (GInputStream *base_stream)
 
 /**
  * g_buffered_input_stream_new_sized:
- * @base_stream: a #GOutputStream.
+ * @base_stream: a #GInputStream.
  * @size: a #gsize.
  * 
  * Creates a new #GBufferedInputStream from the given @base_stream, 
@@ -866,8 +868,8 @@ g_buffered_input_stream_read_byte (GBufferedInputStream  *stream,
 
   if (g_input_stream_is_closed (input_stream))
     {
-      g_set_error (error, G_IO_ERROR, G_IO_ERROR_CLOSED,
-       _("Stream is already closed"));
+      g_set_error_literal (error, G_IO_ERROR, G_IO_ERROR_CLOSED,
+                           _("Stream is already closed"));
       return -1;
     }
 
